@@ -1,5 +1,5 @@
 package QBit::WebInterface::Apache2;
-$QBit::WebInterface::Apache2::VERSION = '0.005';
+$QBit::WebInterface::Apache2::VERSION = '0.006';
 use qbit;
 
 use base qw(QBit::WebInterface);
@@ -8,7 +8,6 @@ use Apache2::Connection;
 use Apache2::RequestIO;
 use Apache2::RequestRec;
 use Apache2::RequestUtil;
-use URI::Escape qw(uri_escape_utf8);
 
 use QBit::WebInterface::Apache2::Request;
 
@@ -40,7 +39,8 @@ sub handler : method {
             ref($self->response->data)
             ? ${$self->response->data}
             : $self->response->data
-        ) if defined($self->response->data);
+          )
+          if defined($self->response->data);
     };
 
     my $status = $self->response->status;
@@ -52,45 +52,6 @@ sub handler : method {
     return Apache2::Const::OK;
 }
 
-sub get_cmd {
-    my ($self) = @_;
-
-    my ($path, $cmd);
-    if ($self->request->uri() =~ /^\/([^?\/]+)(?:\/([^\/?#]+))?/) {
-        ($path, $cmd) = ($1, $2);
-    } else {
-        ($path, $cmd) = $self->default_cmd();
-    }
-
-    $path = '' unless defined($path);
-    $cmd  = '' unless defined($cmd);
-
-    return ($path, $cmd);
-}
-
-sub make_cmd {
-    my ($self, $new_cmd, $new_path, @params) = @_;
-
-    my %vars = defined($params[0])
-      && ref($params[0]) eq 'HASH' ? %{$params[0]} : @params;
-
-    my ($path, $cmd) = $self->get_cmd();
-
-    $path = uri_escape_utf8($self->_get_new_path($new_path, $path));
-    $cmd = uri_escape_utf8($self->_get_new_cmd($new_cmd, $cmd));
-
-    return "/$path/$cmd"
-      . (
-        %vars
-        ? '?'
-          . join(
-            $self->get_option('link_param_separator', '&amp;'),
-            map {uri_escape_utf8($_) . '=' . uri_escape_utf8($vars{$_})} keys(%vars)
-          )
-        : ''
-      );
-}
-
 TRUE;
 
 __END__
